@@ -1,6 +1,6 @@
 globalVariables(
   names = c(
     "walk_number","x","y","value","name", "cum_sum","cum_prod",".tooltip",
-    "step_number",""
+    "step_number"
   )
 )
